@@ -9,11 +9,10 @@
 ***************************************************************************/
 #include "KBlocksDummyAI.h"
 
-#include <stdlib.h>
+#include <QtGlobal>
 
 KBlocksDummyAI::KBlocksDummyAI()
 {
-    mpGame = 0;
     mPauseFlag = false;
 
     mFieldWidth = 0;
@@ -49,8 +48,8 @@ void KBlocksDummyAI::think(GamePlayer_ActionList *actionList)
         return;
     }
 
-    int rotation = rand() % (mRotateCount + 1) - mRotateCount / 2;
-    int motionx = rand() % (mFieldWidth + 1) - mFieldWidth / 2;
+    int rotation = qrand() % (mRotateCount + 1) - mRotateCount / 2;
+    int motionx = qrand() % (mFieldWidth + 1) - mFieldWidth / 2;
 
     if (rotation > 0) {
         for (int i = 0; i < rotation; i++) {
